==> django-fcm-0.0.5.tar.gz: django-fcm-0.0.5/fcm/management/commands/fcm_messenger.py <==
from optparse import make_option
from django.core.management.base import BaseCommand, CommandError

from fcm.utils import get_device_model

Device = get_device_model()


class Command(BaseCommand):
    args = '<device_id message>'
    help = 'Send message through fcm api'

    option_list = BaseCommand.option_list + (
        make_option(
            '--devices',
            action='store_true',
            dest='devices',
            default=False,
            help='List of available devices'),
        make_option(
            '--collapse-key',
            dest='collapse_key',
            default='message',
            help='Set value of collapse_key flag, default is "message"'),
        )

    def handle(self, *args, **options):

        if options['devices']:
            devices = Device.objects.filter(is_active=True)

            self.stdout.write("Devices list:\n")
            for device in devices:
                self.stdout.write("(#%s) %s\n" % (device.id, device.name))
            self.stdout.write("\n")
        else:
            collapse_key = options['collapse_key']
            try:
                id = args[0]
                message = args[1]
            except IndexError:
                raise CommandError(
                    "Invalid params. You have to put all params: "
                    "python manage.py fcm_messenger <device_id> <msg>")

            try:
                device = Device.objects.get(pk=int(id), is_active=True)
            except Device.DoesNotExist:
                raise CommandError(
                    'Unknown device (id=%s). Check list: '
                    'python manage.py fcm_messenger --devices' % id)
            else:
                result = device.send_message(
                        {'message': message}, collapse_key=collapse_key)

                self.stdout.write("[OK] device #%s (%s): %s\n" %
                                  (id, device.name, result))

==> django-fcm-0.0.8.tar.gz: django-fcm-0.0.8/fcm/management/commands/fcm_messenger.py <==
from optparse import make_option
from django.core.management.base import BaseCommand, CommandError

from fcm.utils import get_device_model

Device = get_device_model()


class Command(BaseCommand):
    args = '<device_id message>'
    help = 'Send message through fcm api'

    def add_arguments(self, parser):
        #this store list
        parser.add_argument('device_id', type=int)
        parser.add_argument('msg', type=str)

        parser.add_argument(
            '--devices',
            action='store_true',
            dest='devices',
            default=False,
            help='List of available devices',
        )
        parser.add_argument(
            '--collapse-key',
            dest='collapse_key',
            default='message',
            help='Set value of collapse_key flag, default is "message"',
        )

    def handle(self, *args, **options):
        #print(options)
        if options['devices']:
            devices = Device.objects.filter(is_active=True)

            self.stdout.write("Devices list:\n")
            for device in devices:
                self.stdout.write("(#%s) %s\n" % (device.id, device.name))
            self.stdout.write("\n")
        else:
            collapse_key = options['collapse_key']
            try:
                id = options['device_id']
                message = options['msg']
            except IndexError:
                raise CommandError(
                    "Invalid params. You have to put all params: "
                    "python manage.py fcm_messenger <device_id> <msg>")

            try:
                device = Device.objects.get(pk=int(id), is_active=True)
            except Device.DoesNotExist:
                raise CommandError(
                    'Unknown device (id=%s). Check list: '
                    'python manage.py fcm_messenger --devices' % id)
            else:
                result = device.send_message(
                        {'message': message}, collapse_key=collapse_key)

                self.stdout.write("[OK] device #%s (%s): %s\n" %
                                  (id, device.name, result))
